@@ -15,6 +15,11 @@ import os
 
 
 environments = os.getenv('ENVIRONMENTS').split(' ')
+username = os.getenv('GITLAB_TERRAFORM_DEPLOY_TOKEN_USERNAME').split(' ')
+secret = os.getenv('GITLAB_TERRAFORM_DEPLOY_TOKEN_SECRET').split(' ')
+
+os.system(f'git config --global url."https://{username}:{secret}@gitlab.com/miquido/terraform".insteadOf "ssh://git@gitlab.com/miquido/terraform"')
+os.system('git config --global url."https://github.com".insteadOf "ssh://git@github.com"')
 
 for environment in environments:
     os.chdir(environment)
